pub struct Scrollbar {
pub size_inner_pane_x: Property<Size>,
pub size_inner_pane_y: Property<Size>,
pub scroll_x: Property<f64>,
pub scroll_y: Property<f64>,
}Expand description
A combination of a clipping area (nearly identical to a Frame,) and an
inner panel that can be scrolled on zero or more axes. Scroller coordinates with each chassis to
create native scrolling containers, which pass native scroll events back to Engine. In turn,
Scroller translates its children to reflect the current scroll position.
When both scrolling axes are disabled, Scroller acts exactly like a Frame, with a possibly-
transformed Group surrounding its contents.
Fields
size_inner_pane_x: Property<Size>size_inner_pane_y: Property<Size>scroll_x: Property<f64>scroll_y: Property<f64>Trait Implementations
Sourceimpl CoercionRules for Scrollbar
impl CoercionRules for Scrollbar
Sourceimpl<'de> Deserialize<'de> for Scrollbar
impl<'de> Deserialize<'de> for Scrollbar
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<Scrollbar, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<Scrollbar, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl HelperFunctions for Scrollbar
impl HelperFunctions for Scrollbar
impl ImplToFromPaxAny for Scrollbar
Sourceimpl Interpolatable for Scrollbar
impl Interpolatable for Scrollbar
fn interpolate(&self, _other: &Self, _t: f64) -> Self
Sourceimpl Serialize for Scrollbar
impl Serialize for Scrollbar
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl ToPaxValue for Scrollbar
impl ToPaxValue for Scrollbar
fn to_pax_value(self) -> PaxValue