ArrayTuple

Struct ArrayTuple 

pub struct ArrayTuple<T = (JsValue,)>
where T: JsTuple,
{ /* private fields */ }

Implementations

Source

impl ArrayTuple

pub fn new1<T1>(t1: &T1) -> ArrayTuple<(T1,)>
where T1: ErasableGenericBorrow<JsValue>, ArrayTuple<(T1,)>: ErasableGenericOwn<ArrayTuple>,

Creates a new JS array typed as a 1-tuple.

Source

impl ArrayTuple

pub fn new2<T1, T2>(t1: &T1, t2: &T2) -> ArrayTuple<(T1, T2)>
where T1: ErasableGenericBorrow<JsValue>, T2: ErasableGenericBorrow<JsValue>, ArrayTuple<(T1, T2)>: ErasableGenericOwn<ArrayTuple<(JsValue, JsValue)>>,

Creates a new JS array typed as a 2-tuple.

Source

impl ArrayTuple

pub fn new3<T1, T2, T3>(t1: &T1, t2: &T2, t3: &T3) -> ArrayTuple<(T1, T2, T3)>
where T1: ErasableGenericBorrow<JsValue>, T2: ErasableGenericBorrow<JsValue>, T3: ErasableGenericBorrow<JsValue>, ArrayTuple<(T1, T2, T3)>: ErasableGenericOwn<ArrayTuple<(JsValue, JsValue, JsValue)>>,

Creates a new JS array typed as a 3-tuple.

Source

impl ArrayTuple

pub fn new4<T1, T2, T3, T4>( t1: &T1, t2: &T2, t3: &T3, t4: &T4, ) -> ArrayTuple<(T1, T2, T3, T4)>
where T1: ErasableGenericBorrow<JsValue>, T2: ErasableGenericBorrow<JsValue>, T3: ErasableGenericBorrow<JsValue>, T4: ErasableGenericBorrow<JsValue>, ArrayTuple<(T1, T2, T3, T4)>: ErasableGenericOwn<ArrayTuple<(JsValue, JsValue, JsValue, JsValue)>>,

Creates a new JS array typed as a 4-tuple.

Source

impl ArrayTuple

pub fn new5<T1, T2, T3, T4, T5>( t1: &T1, t2: &T2, t3: &T3, t4: &T4, t5: &T5, ) -> ArrayTuple<(T1, T2, T3, T4, T5)>
where T1: ErasableGenericBorrow<JsValue>, T2: ErasableGenericBorrow<JsValue>, T3: ErasableGenericBorrow<JsValue>, T4: ErasableGenericBorrow<JsValue>, T5: ErasableGenericBorrow<JsValue>, ArrayTuple<(T1, T2, T3, T4, T5)>: ErasableGenericOwn<ArrayTuple<(JsValue, JsValue, JsValue, JsValue, JsValue)>>,

Creates a new JS array typed as a 5-tuple.

Source

impl ArrayTuple

pub fn new6<T1, T2, T3, T4, T5, T6>( t1: &T1, t2: &T2, t3: &T3, t4: &T4, t5: &T5, t6: &T6, ) -> ArrayTuple<(T1, T2, T3, T4, T5, T6)>
where T1: ErasableGenericBorrow<JsValue>, T2: ErasableGenericBorrow<JsValue>, T3: ErasableGenericBorrow<JsValue>, T4: ErasableGenericBorrow<JsValue>, T5: ErasableGenericBorrow<JsValue>, T6: ErasableGenericBorrow<JsValue>, ArrayTuple<(T1, T2, T3, T4, T5, T6)>: ErasableGenericOwn<ArrayTuple<(JsValue, JsValue, JsValue, JsValue, JsValue, JsValue)>>,

Creates a new JS array typed as a 6-tuple.

Source

impl ArrayTuple

pub fn new7<T1, T2, T3, T4, T5, T6, T7>( t1: &T1, t2: &T2, t3: &T3, t4: &T4, t5: &T5, t6: &T6, t7: &T7, ) -> ArrayTuple<(T1, T2, T3, T4, T5, T6, T7)>
where T1: ErasableGenericBorrow<JsValue>, T2: ErasableGenericBorrow<JsValue>, T3: ErasableGenericBorrow<JsValue>, T4: ErasableGenericBorrow<JsValue>, T5: ErasableGenericBorrow<JsValue>, T6: ErasableGenericBorrow<JsValue>, T7: ErasableGenericBorrow<JsValue>, ArrayTuple<(T1, T2, T3, T4, T5, T6, T7)>: ErasableGenericOwn<ArrayTuple<(JsValue, JsValue, JsValue, JsValue, JsValue, JsValue, JsValue)>>,

Creates a new JS array typed as a 7-tuple.

Source

impl ArrayTuple

pub fn new8<T1, T2, T3, T4, T5, T6, T7, T8>( t1: &T1, t2: &T2, t3: &T3, t4: &T4, t5: &T5, t6: &T6, t7: &T7, t8: &T8, ) -> ArrayTuple<(T1, T2, T3, T4, T5, T6, T7, T8)>
where T1: ErasableGenericBorrow<JsValue>, T2: ErasableGenericBorrow<JsValue>, T3: ErasableGenericBorrow<JsValue>, T4: ErasableGenericBorrow<JsValue>, T5: ErasableGenericBorrow<JsValue>, T6: ErasableGenericBorrow<JsValue>, T7: ErasableGenericBorrow<JsValue>, T8: ErasableGenericBorrow<JsValue>, ArrayTuple<(T1, T2, T3, T4, T5, T6, T7, T8)>: ErasableGenericOwn<ArrayTuple<(JsValue, JsValue, JsValue, JsValue, JsValue, JsValue, JsValue, JsValue)>>,

Creates a new JS array typed as a 8-tuple.

Source

impl<T> ArrayTuple<T>
where T: JsTuple1,

pub fn get0(&self) -> <T as JsTuple1>::T1
where <T as JsTuple1>::T1: ErasableGenericOwn<<(JsValue,) as JsTuple1>::T1>,

Gets the 1st item

Source

impl<T> ArrayTuple<T>
where T: JsTuple2,

pub fn get1(&self) -> <T as JsTuple2>::T2
where <T as JsTuple2>::T2: ErasableGenericOwn<<(JsValue, JsValue) as JsTuple2>::T2>,

Gets the 2nd item

Source

impl<T> ArrayTuple<T>
where T: JsTuple3,

pub fn get2(&self) -> <T as JsTuple3>::T3
where <T as JsTuple3>::T3: ErasableGenericOwn<<(JsValue, JsValue, JsValue) as JsTuple3>::T3>,

Gets the 3rd item

Source

impl<T> ArrayTuple<T>
where T: JsTuple4,

pub fn get3(&self) -> <T as JsTuple4>::T4
where <T as JsTuple4>::T4: ErasableGenericOwn<<(JsValue, JsValue, JsValue, JsValue) as JsTuple4>::T4>,

Gets the 4th item

Source

impl<T> ArrayTuple<T>
where T: JsTuple5,

pub fn get4(&self) -> <T as JsTuple5>::T5
where <T as JsTuple5>::T5: ErasableGenericOwn<<(JsValue, JsValue, JsValue, JsValue, JsValue) as JsTuple5>::T5>,

Gets the 5th item

Source

impl<T> ArrayTuple<T>
where T: JsTuple6,

pub fn get5(&self) -> <T as JsTuple6>::T6
where <T as JsTuple6>::T6: ErasableGenericOwn<<(JsValue, JsValue, JsValue, JsValue, JsValue, JsValue) as JsTuple6>::T6>,

Gets the 6th item

Source

impl<T> ArrayTuple<T>
where T: JsTuple7,

pub fn get6(&self) -> <T as JsTuple7>::T7
where <T as JsTuple7>::T7: ErasableGenericOwn<<(JsValue, JsValue, JsValue, JsValue, JsValue, JsValue, JsValue) as JsTuple7>::T7>,

Gets the 7th item

Source

impl<T> ArrayTuple<T>
where T: JsTuple8,

pub fn get7(&self) -> <T as JsTuple8>::T8
where <T as JsTuple8>::T8: ErasableGenericOwn<<(JsValue, JsValue, JsValue, JsValue, JsValue, JsValue, JsValue, JsValue) as JsTuple8>::T8>,

Gets the 8th item

Source

impl<T> ArrayTuple<T>
where T: JsTuple1,

pub fn set0(&self, value: &<T as JsTuple1>::T1)
where <T as JsTuple1>::T1: ErasableGenericBorrow<<(JsValue,) as JsTuple1>::T1>,

Sets the 1st item

Source

impl<T> ArrayTuple<T>
where T: JsTuple2,

pub fn set1(&self, value: &<T as JsTuple2>::T2)
where <T as JsTuple2>::T2: ErasableGenericBorrow<<(JsValue, JsValue) as JsTuple2>::T2>,

Sets the 2nd item

Source

impl<T> ArrayTuple<T>
where T: JsTuple3,

pub fn set2(&self, value: &<T as JsTuple3>::T3)
where <T as JsTuple3>::T3: ErasableGenericBorrow<<(JsValue, JsValue, JsValue) as JsTuple3>::T3>,

Sets the 3rd item

Source

impl<T> ArrayTuple<T>
where T: JsTuple4,

pub fn set3(&self, value: &<T as JsTuple4>::T4)
where <T as JsTuple4>::T4: ErasableGenericBorrow<<(JsValue, JsValue, JsValue, JsValue) as JsTuple4>::T4>,

Sets the 4th item

Source

impl<T> ArrayTuple<T>
where T: JsTuple5,

pub fn set4(&self, value: &<T as JsTuple5>::T5)
where <T as JsTuple5>::T5: ErasableGenericBorrow<<(JsValue, JsValue, JsValue, JsValue, JsValue) as JsTuple5>::T5>,

Sets the 5th item

Source

impl<T> ArrayTuple<T>
where T: JsTuple6,

pub fn set5(&self, value: &<T as JsTuple6>::T6)
where <T as JsTuple6>::T6: ErasableGenericBorrow<<(JsValue, JsValue, JsValue, JsValue, JsValue, JsValue) as JsTuple6>::T6>,

Sets the 6th item

Source

impl<T> ArrayTuple<T>
where T: JsTuple7,

pub fn set6(&self, value: &<T as JsTuple7>::T7)
where <T as JsTuple7>::T7: ErasableGenericBorrow<<(JsValue, JsValue, JsValue, JsValue, JsValue, JsValue, JsValue) as JsTuple7>::T7>,

Sets the 7th item

Source

impl<T> ArrayTuple<T>
where T: JsTuple8,

pub fn set7(&self, value: &<T as JsTuple8>::T8)
where <T as JsTuple8>::T8: ErasableGenericBorrow<<(JsValue, JsValue, JsValue, JsValue, JsValue, JsValue, JsValue, JsValue) as JsTuple8>::T8>,

Sets the 8th item

Source

impl<T> ArrayTuple<T>
where T: JsTuple,

pub fn len(&self) -> usize

Get the static arity of the ArrayTuple type.

Source

impl<T1> ArrayTuple<(T1,)>
where T1: JsGeneric,

pub fn first(&self) -> T1

Get the first element of the ArrayTuple

pub fn last(&self) -> T1

Get the last element of the ArrayTuple

pub fn into_tuple(self) -> (T1,)

Convert the ArrayTuple into its corresponding Rust tuple.

pub fn into_parts(self) -> (T1,)

👎Deprecated:

renamed to into_tuple

Deprecated alias for ArrayTuple::into_tuple.

pub fn new(get0: &T1) -> ArrayTuple<(T1,)>

Create a new ArrayTuple from the corresponding parts.

Example
use js_sys::{ArrayTuple, JsString};

let tuple = ArrayTuple::<JsString, JsString>::new(&"a".into(), &"b".into());

Note: You must specify the T using ::<...> syntax on ArrayTuple. Alternatively, use new1, new2, etc. for type inference from the left-hand side.

Source

impl<T1, T2> ArrayTuple<(T1, T2)>
where T1: JsGeneric, T2: JsGeneric,

pub fn first(&self) -> T1

Get the first element of the ArrayTuple

pub fn last(&self) -> T2

Get the last element of the ArrayTuple

pub fn into_tuple(self) -> (T1, T2)

Convert the ArrayTuple into its corresponding Rust tuple.

pub fn into_parts(self) -> (T1, T2)

👎Deprecated:

renamed to into_tuple

Deprecated alias for ArrayTuple::into_tuple.

pub fn new(get0: &T1, get1: &T2) -> ArrayTuple<(T1, T2)>

Create a new ArrayTuple from the corresponding parts.

Example
use js_sys::{ArrayTuple, JsString};

let tuple = ArrayTuple::<JsString, JsString>::new(&"a".into(), &"b".into());

Note: You must specify the T using ::<...> syntax on ArrayTuple. Alternatively, use new1, new2, etc. for type inference from the left-hand side.

Source

impl<T1, T2, T3> ArrayTuple<(T1, T2, T3)>
where T1: JsGeneric, T2: JsGeneric, T3: JsGeneric,

pub fn first(&self) -> T1

Get the first element of the ArrayTuple

pub fn last(&self) -> T3

Get the last element of the ArrayTuple

pub fn into_tuple(self) -> (T1, T2, T3)

Convert the ArrayTuple into its corresponding Rust tuple.

pub fn into_parts(self) -> (T1, T2, T3)

👎Deprecated:

renamed to into_tuple

Deprecated alias for ArrayTuple::into_tuple.

pub fn new(get0: &T1, get1: &T2, get2: &T3) -> ArrayTuple<(T1, T2, T3)>

Create a new ArrayTuple from the corresponding parts.

Example
use js_sys::{ArrayTuple, JsString};

let tuple = ArrayTuple::<JsString, JsString>::new(&"a".into(), &"b".into());

Note: You must specify the T using ::<...> syntax on ArrayTuple. Alternatively, use new1, new2, etc. for type inference from the left-hand side.

Source

impl<T1, T2, T3, T4> ArrayTuple<(T1, T2, T3, T4)>
where T1: JsGeneric, T2: JsGeneric, T3: JsGeneric, T4: JsGeneric,

pub fn first(&self) -> T1

Get the first element of the ArrayTuple

pub fn last(&self) -> T4

Get the last element of the ArrayTuple

pub fn into_tuple(self) -> (T1, T2, T3, T4)

Convert the ArrayTuple into its corresponding Rust tuple.

pub fn into_parts(self) -> (T1, T2, T3, T4)

👎Deprecated:

renamed to into_tuple

Deprecated alias for ArrayTuple::into_tuple.

pub fn new( get0: &T1, get1: &T2, get2: &T3, get3: &T4, ) -> ArrayTuple<(T1, T2, T3, T4)>

Create a new ArrayTuple from the corresponding parts.

Example
use js_sys::{ArrayTuple, JsString};

let tuple = ArrayTuple::<JsString, JsString>::new(&"a".into(), &"b".into());

Note: You must specify the T using ::<...> syntax on ArrayTuple. Alternatively, use new1, new2, etc. for type inference from the left-hand side.

Source

impl<T1, T2, T3, T4, T5> ArrayTuple<(T1, T2, T3, T4, T5)>
where T1: JsGeneric, T2: JsGeneric, T3: JsGeneric, T4: JsGeneric, T5: JsGeneric,

pub fn first(&self) -> T1

Get the first element of the ArrayTuple

pub fn last(&self) -> T5

Get the last element of the ArrayTuple

pub fn into_tuple(self) -> (T1, T2, T3, T4, T5)

Convert the ArrayTuple into its corresponding Rust tuple.

pub fn into_parts(self) -> (T1, T2, T3, T4, T5)

👎Deprecated:

renamed to into_tuple

Deprecated alias for ArrayTuple::into_tuple.

pub fn new( get0: &T1, get1: &T2, get2: &T3, get3: &T4, get4: &T5, ) -> ArrayTuple<(T1, T2, T3, T4, T5)>

Create a new ArrayTuple from the corresponding parts.

Example
use js_sys::{ArrayTuple, JsString};

let tuple = ArrayTuple::<JsString, JsString>::new(&"a".into(), &"b".into());

Note: You must specify the T using ::<...> syntax on ArrayTuple. Alternatively, use new1, new2, etc. for type inference from the left-hand side.

Source

impl<T1, T2, T3, T4, T5, T6> ArrayTuple<(T1, T2, T3, T4, T5, T6)>
where T1: JsGeneric, T2: JsGeneric, T3: JsGeneric, T4: JsGeneric, T5: JsGeneric, T6: JsGeneric,

pub fn first(&self) -> T1

Get the first element of the ArrayTuple

pub fn last(&self) -> T6

Get the last element of the ArrayTuple

pub fn into_tuple(self) -> (T1, T2, T3, T4, T5, T6)

Convert the ArrayTuple into its corresponding Rust tuple.

pub fn into_parts(self) -> (T1, T2, T3, T4, T5, T6)

👎Deprecated:

renamed to into_tuple

Deprecated alias for ArrayTuple::into_tuple.

pub fn new( get0: &T1, get1: &T2, get2: &T3, get3: &T4, get4: &T5, get5: &T6, ) -> ArrayTuple<(T1, T2, T3, T4, T5, T6)>

Create a new ArrayTuple from the corresponding parts.

Example
use js_sys::{ArrayTuple, JsString};

let tuple = ArrayTuple::<JsString, JsString>::new(&"a".into(), &"b".into());

Note: You must specify the T using ::<...> syntax on ArrayTuple. Alternatively, use new1, new2, etc. for type inference from the left-hand side.

Source

impl<T1, T2, T3, T4, T5, T6, T7> ArrayTuple<(T1, T2, T3, T4, T5, T6, T7)>
where T1: JsGeneric, T2: JsGeneric, T3: JsGeneric, T4: JsGeneric, T5: JsGeneric, T6: JsGeneric, T7: JsGeneric,

pub fn first(&self) -> T1

Get the first element of the ArrayTuple

pub fn last(&self) -> T7

Get the last element of the ArrayTuple

pub fn into_tuple(self) -> (T1, T2, T3, T4, T5, T6, T7)

Convert the ArrayTuple into its corresponding Rust tuple.

pub fn into_parts(self) -> (T1, T2, T3, T4, T5, T6, T7)

👎Deprecated:

renamed to into_tuple

Deprecated alias for ArrayTuple::into_tuple.

pub fn new( get0: &T1, get1: &T2, get2: &T3, get3: &T4, get4: &T5, get5: &T6, get6: &T7, ) -> ArrayTuple<(T1, T2, T3, T4, T5, T6, T7)>

Create a new ArrayTuple from the corresponding parts.

Example
use js_sys::{ArrayTuple, JsString};

let tuple = ArrayTuple::<JsString, JsString>::new(&"a".into(), &"b".into());

Note: You must specify the T using ::<...> syntax on ArrayTuple. Alternatively, use new1, new2, etc. for type inference from the left-hand side.

Source

impl<T1, T2, T3, T4, T5, T6, T7, T8> ArrayTuple<(T1, T2, T3, T4, T5, T6, T7, T8)>
where T1: JsGeneric, T2: JsGeneric, T3: JsGeneric, T4: JsGeneric, T5: JsGeneric, T6: JsGeneric, T7: JsGeneric, T8: JsGeneric,

pub fn first(&self) -> T1

Get the first element of the ArrayTuple

pub fn last(&self) -> T8

Get the last element of the ArrayTuple

pub fn into_tuple(self) -> (T1, T2, T3, T4, T5, T6, T7, T8)

Convert the ArrayTuple into its corresponding Rust tuple.

pub fn into_parts(self) -> (T1, T2, T3, T4, T5, T6, T7, T8)

👎Deprecated:

renamed to into_tuple

Deprecated alias for ArrayTuple::into_tuple.

pub fn new( get0: &T1, get1: &T2, get2: &T3, get3: &T4, get4: &T5, get5: &T6, get6: &T7, get7: &T8, ) -> ArrayTuple<(T1, T2, T3, T4, T5, T6, T7, T8)>

Create a new ArrayTuple from the corresponding parts.

Example
use js_sys::{ArrayTuple, JsString};

let tuple = ArrayTuple::<JsString, JsString>::new(&"a".into(), &"b".into());

Note: You must specify the T using ::<...> syntax on ArrayTuple. Alternatively, use new1, new2, etc. for type inference from the left-hand side.

Methods from Deref<Target = Object>

pub fn constructor(&self) -> Function

The constructor property returns a reference to the Object constructor function that created the instance object.

MDN documentation

pub fn has_own_property(&self, property: &JsValue) -> bool

👎Deprecated:

Use Object::hasOwn instead.

The hasOwnProperty() method returns a boolean indicating whether the object has the specified property as its own property (as opposed to inheriting it).

MDN documentation

pub fn is_prototype_of(&self, value: &JsValue) -> bool

The isPrototypeOf() method checks if an object exists in another object’s prototype chain.

MDN documentation

pub fn property_is_enumerable(&self, property: &JsValue) -> bool

The propertyIsEnumerable() method returns a Boolean indicating whether the specified property is enumerable.

MDN documentation

pub fn to_locale_string(&self) -> JsString

The toLocaleString() method returns a string representing the object. This method is meant to be overridden by derived objects for locale-specific purposes.

MDN documentation

pub fn to_string(&self) -> JsString

The toString() method returns a string representing the object.

MDN documentation

pub fn to_js_string(&self) -> JsString

The toString() method returns a string representing the object.

MDN documentation

pub fn value_of(&self) -> Object

The valueOf() method returns the primitive value of the specified object.

MDN documentation

Methods from Deref<Target = JsValue>

pub const NULL: JsValue

pub const UNDEFINED: JsValue

pub const TRUE: JsValue

pub const FALSE: JsValue

pub fn into_serde<T>(&self) -> Result<T, Error>
where T: for<'a> Deserialize<'a>,

👎Deprecated:

causes dependency cycles, use serde-wasm-bindgen or gloo_utils::format::JsValueSerdeExt instead

Invokes JSON.stringify on this value and then parses the resulting JSON into an arbitrary Rust value.

This function is deprecated, due to creating a dependency cycle in some circumstances. Use serde-wasm-bindgen or gloo_utils::format::JsValueSerdeExt instead.

This function will first call JSON.stringify on the JsValue itself. The resulting string is then passed into Rust which then parses it as JSON into the resulting value.

Usage of this API requires activating the serde-serialize feature of the wasm-bindgen crate.

Errors

Returns any error encountered when parsing the JSON into a T.

pub fn as_f64(&self) -> Option<f64>

Returns the f64 value of this JS value if it’s an instance of a number.

If this JS value is not an instance of a number then this returns None.

pub fn is_string(&self) -> bool

Tests whether this JS value is a JS string.

pub fn as_string(&self) -> Option<String>

If this JS value is a string value, this function copies the JS string value into Wasm linear memory, encoded as UTF-8, and returns it as a Rust String.

To avoid the copying and re-encoding, consider the JsString::try_from() function from js-sys instead.

If this JS value is not an instance of a string or if it’s not valid utf-8 then this returns None.

UTF-16 vs UTF-8

JavaScript strings in general are encoded as UTF-16, but Rust strings are encoded as UTF-8. This can cause the Rust string to look a bit different than the JS string sometimes. For more details see the documentation about the str type which contains a few caveats about the encodings.

pub fn as_bool(&self) -> Option<bool>

Returns the bool value of this JS value if it’s an instance of a boolean.

If this JS value is not an instance of a boolean then this returns None.

pub fn is_null(&self) -> bool

Tests whether this JS value is null

pub fn is_undefined(&self) -> bool

Tests whether this JS value is undefined

pub fn is_null_or_undefined(&self) -> bool

Tests whether this JS value is null or undefined

pub fn is_symbol(&self) -> bool

Tests whether the type of this JS value is symbol

pub fn is_object(&self) -> bool

Tests whether typeof self == "object" && self !== null.

pub fn is_array(&self) -> bool

Tests whether this JS value is an instance of Array.

pub fn is_function(&self) -> bool

Tests whether the type of this JS value is function.

pub fn is_bigint(&self) -> bool

Tests whether the type of this JS value is bigint.

pub fn js_typeof(&self) -> JsValue

Applies the unary typeof JS operator on a JsValue.

MDN documentation

pub fn js_in(&self, obj: &JsValue) -> bool

Applies the binary in JS operator on the two JsValues.

MDN documentation

pub fn is_truthy(&self) -> bool

Tests whether the value is “truthy”.

pub fn is_falsy(&self) -> bool

Tests whether the value is “falsy”.

pub fn loose_eq(&self, other: &JsValue) -> bool

Compare two JsValues for equality, using the == operator in JS.

MDN documentation

pub fn bit_not(&self) -> JsValue

Applies the unary ~ JS operator on a JsValue.

MDN documentation

pub fn unsigned_shr(&self, rhs: &JsValue) -> u32

Applies the binary >>> JS operator on the two JsValues.

MDN documentation

pub fn checked_div(&self, rhs: &JsValue) -> JsValue

Applies the binary / JS operator on two JsValues, catching and returning any RangeError thrown.

MDN documentation

pub fn pow(&self, rhs: &JsValue) -> JsValue

Applies the binary ** JS operator on the two JsValues.

MDN documentation

pub fn lt(&self, other: &JsValue) -> bool

Applies the binary < JS operator on the two JsValues.

MDN documentation

pub fn le(&self, other: &JsValue) -> bool

Applies the binary <= JS operator on the two JsValues.

MDN documentation

pub fn ge(&self, other: &JsValue) -> bool

Applies the binary >= JS operator on the two JsValues.

MDN documentation

pub fn gt(&self, other: &JsValue) -> bool

Applies the binary > JS operator on the two JsValues.

MDN documentation

pub fn unchecked_into_f64(&self) -> f64

Applies the unary + JS operator on a JsValue. Can throw.

MDN documentation