pub struct ArrayTuple<T = (JsValue,)>where
T: JsTuple,{ /* private fields */ }Implementations
Sourceimpl ArrayTuple
impl ArrayTuple
Sourcepub fn new1<T1>(t1: &T1) -> ArrayTuple<(T1,)>
pub fn new1<T1>(t1: &T1) -> ArrayTuple<(T1,)>
Creates a new JS array typed as a 1-tuple.
Sourceimpl ArrayTuple
impl ArrayTuple
Sourcepub fn new2<T1, T2>(t1: &T1, t2: &T2) -> ArrayTuple<(T1, T2)>where
T1: ErasableGenericBorrow<JsValue>,
T2: ErasableGenericBorrow<JsValue>,
ArrayTuple<(T1, T2)>: ErasableGenericOwn<ArrayTuple<(JsValue, JsValue)>>,
pub fn new2<T1, T2>(t1: &T1, t2: &T2) -> ArrayTuple<(T1, T2)>where
T1: ErasableGenericBorrow<JsValue>,
T2: ErasableGenericBorrow<JsValue>,
ArrayTuple<(T1, T2)>: ErasableGenericOwn<ArrayTuple<(JsValue, JsValue)>>,
Creates a new JS array typed as a 2-tuple.
Sourceimpl ArrayTuple
impl ArrayTuple
Sourcepub fn new3<T1, T2, T3>(t1: &T1, t2: &T2, t3: &T3) -> ArrayTuple<(T1, T2, T3)>where
T1: ErasableGenericBorrow<JsValue>,
T2: ErasableGenericBorrow<JsValue>,
T3: ErasableGenericBorrow<JsValue>,
ArrayTuple<(T1, T2, T3)>: ErasableGenericOwn<ArrayTuple<(JsValue, JsValue, JsValue)>>,
pub fn new3<T1, T2, T3>(t1: &T1, t2: &T2, t3: &T3) -> ArrayTuple<(T1, T2, T3)>where
T1: ErasableGenericBorrow<JsValue>,
T2: ErasableGenericBorrow<JsValue>,
T3: ErasableGenericBorrow<JsValue>,
ArrayTuple<(T1, T2, T3)>: ErasableGenericOwn<ArrayTuple<(JsValue, JsValue, JsValue)>>,
Creates a new JS array typed as a 3-tuple.
Sourceimpl ArrayTuple
impl ArrayTuple
Sourcepub fn new4<T1, T2, T3, T4>(
t1: &T1,
t2: &T2,
t3: &T3,
t4: &T4,
) -> ArrayTuple<(T1, T2, T3, T4)>where
T1: ErasableGenericBorrow<JsValue>,
T2: ErasableGenericBorrow<JsValue>,
T3: ErasableGenericBorrow<JsValue>,
T4: ErasableGenericBorrow<JsValue>,
ArrayTuple<(T1, T2, T3, T4)>: ErasableGenericOwn<ArrayTuple<(JsValue, JsValue, JsValue, JsValue)>>,
pub fn new4<T1, T2, T3, T4>(
t1: &T1,
t2: &T2,
t3: &T3,
t4: &T4,
) -> ArrayTuple<(T1, T2, T3, T4)>where
T1: ErasableGenericBorrow<JsValue>,
T2: ErasableGenericBorrow<JsValue>,
T3: ErasableGenericBorrow<JsValue>,
T4: ErasableGenericBorrow<JsValue>,
ArrayTuple<(T1, T2, T3, T4)>: ErasableGenericOwn<ArrayTuple<(JsValue, JsValue, JsValue, JsValue)>>,
Creates a new JS array typed as a 4-tuple.
Sourceimpl ArrayTuple
impl ArrayTuple
Sourcepub fn new5<T1, T2, T3, T4, T5>(
t1: &T1,
t2: &T2,
t3: &T3,
t4: &T4,
t5: &T5,
) -> ArrayTuple<(T1, T2, T3, T4, T5)>where
T1: ErasableGenericBorrow<JsValue>,
T2: ErasableGenericBorrow<JsValue>,
T3: ErasableGenericBorrow<JsValue>,
T4: ErasableGenericBorrow<JsValue>,
T5: ErasableGenericBorrow<JsValue>,
ArrayTuple<(T1, T2, T3, T4, T5)>: ErasableGenericOwn<ArrayTuple<(JsValue, JsValue, JsValue, JsValue, JsValue)>>,
pub fn new5<T1, T2, T3, T4, T5>(
t1: &T1,
t2: &T2,
t3: &T3,
t4: &T4,
t5: &T5,
) -> ArrayTuple<(T1, T2, T3, T4, T5)>where
T1: ErasableGenericBorrow<JsValue>,
T2: ErasableGenericBorrow<JsValue>,
T3: ErasableGenericBorrow<JsValue>,
T4: ErasableGenericBorrow<JsValue>,
T5: ErasableGenericBorrow<JsValue>,
ArrayTuple<(T1, T2, T3, T4, T5)>: ErasableGenericOwn<ArrayTuple<(JsValue, JsValue, JsValue, JsValue, JsValue)>>,
Creates a new JS array typed as a 5-tuple.
Sourceimpl ArrayTuple
impl ArrayTuple
Sourcepub fn new6<T1, T2, T3, T4, T5, T6>(
t1: &T1,
t2: &T2,
t3: &T3,
t4: &T4,
t5: &T5,
t6: &T6,
) -> ArrayTuple<(T1, T2, T3, T4, T5, T6)>where
T1: ErasableGenericBorrow<JsValue>,
T2: ErasableGenericBorrow<JsValue>,
T3: ErasableGenericBorrow<JsValue>,
T4: ErasableGenericBorrow<JsValue>,
T5: ErasableGenericBorrow<JsValue>,
T6: ErasableGenericBorrow<JsValue>,
ArrayTuple<(T1, T2, T3, T4, T5, T6)>: ErasableGenericOwn<ArrayTuple<(JsValue, JsValue, JsValue, JsValue, JsValue, JsValue)>>,
pub fn new6<T1, T2, T3, T4, T5, T6>(
t1: &T1,
t2: &T2,
t3: &T3,
t4: &T4,
t5: &T5,
t6: &T6,
) -> ArrayTuple<(T1, T2, T3, T4, T5, T6)>where
T1: ErasableGenericBorrow<JsValue>,
T2: ErasableGenericBorrow<JsValue>,
T3: ErasableGenericBorrow<JsValue>,
T4: ErasableGenericBorrow<JsValue>,
T5: ErasableGenericBorrow<JsValue>,
T6: ErasableGenericBorrow<JsValue>,
ArrayTuple<(T1, T2, T3, T4, T5, T6)>: ErasableGenericOwn<ArrayTuple<(JsValue, JsValue, JsValue, JsValue, JsValue, JsValue)>>,
Creates a new JS array typed as a 6-tuple.
Sourceimpl ArrayTuple
impl ArrayTuple
Sourcepub fn new7<T1, T2, T3, T4, T5, T6, T7>(
t1: &T1,
t2: &T2,
t3: &T3,
t4: &T4,
t5: &T5,
t6: &T6,
t7: &T7,
) -> ArrayTuple<(T1, T2, T3, T4, T5, T6, T7)>where
T1: ErasableGenericBorrow<JsValue>,
T2: ErasableGenericBorrow<JsValue>,
T3: ErasableGenericBorrow<JsValue>,
T4: ErasableGenericBorrow<JsValue>,
T5: ErasableGenericBorrow<JsValue>,
T6: ErasableGenericBorrow<JsValue>,
T7: ErasableGenericBorrow<JsValue>,
ArrayTuple<(T1, T2, T3, T4, T5, T6, T7)>: ErasableGenericOwn<ArrayTuple<(JsValue, JsValue, JsValue, JsValue, JsValue, JsValue, JsValue)>>,
pub fn new7<T1, T2, T3, T4, T5, T6, T7>(
t1: &T1,
t2: &T2,
t3: &T3,
t4: &T4,
t5: &T5,
t6: &T6,
t7: &T7,
) -> ArrayTuple<(T1, T2, T3, T4, T5, T6, T7)>where
T1: ErasableGenericBorrow<JsValue>,
T2: ErasableGenericBorrow<JsValue>,
T3: ErasableGenericBorrow<JsValue>,
T4: ErasableGenericBorrow<JsValue>,
T5: ErasableGenericBorrow<JsValue>,
T6: ErasableGenericBorrow<JsValue>,
T7: ErasableGenericBorrow<JsValue>,
ArrayTuple<(T1, T2, T3, T4, T5, T6, T7)>: ErasableGenericOwn<ArrayTuple<(JsValue, JsValue, JsValue, JsValue, JsValue, JsValue, JsValue)>>,
Creates a new JS array typed as a 7-tuple.
Sourceimpl ArrayTuple
impl ArrayTuple
Sourcepub fn new8<T1, T2, T3, T4, T5, T6, T7, T8>(
t1: &T1,
t2: &T2,
t3: &T3,
t4: &T4,
t5: &T5,
t6: &T6,
t7: &T7,
t8: &T8,
) -> ArrayTuple<(T1, T2, T3, T4, T5, T6, T7, T8)>where
T1: ErasableGenericBorrow<JsValue>,
T2: ErasableGenericBorrow<JsValue>,
T3: ErasableGenericBorrow<JsValue>,
T4: ErasableGenericBorrow<JsValue>,
T5: ErasableGenericBorrow<JsValue>,
T6: ErasableGenericBorrow<JsValue>,
T7: ErasableGenericBorrow<JsValue>,
T8: ErasableGenericBorrow<JsValue>,
ArrayTuple<(T1, T2, T3, T4, T5, T6, T7, T8)>: ErasableGenericOwn<ArrayTuple<(JsValue, JsValue, JsValue, JsValue, JsValue, JsValue, JsValue, JsValue)>>,
pub fn new8<T1, T2, T3, T4, T5, T6, T7, T8>(
t1: &T1,
t2: &T2,
t3: &T3,
t4: &T4,
t5: &T5,
t6: &T6,
t7: &T7,
t8: &T8,
) -> ArrayTuple<(T1, T2, T3, T4, T5, T6, T7, T8)>where
T1: ErasableGenericBorrow<JsValue>,
T2: ErasableGenericBorrow<JsValue>,
T3: ErasableGenericBorrow<JsValue>,
T4: ErasableGenericBorrow<JsValue>,
T5: ErasableGenericBorrow<JsValue>,
T6: ErasableGenericBorrow<JsValue>,
T7: ErasableGenericBorrow<JsValue>,
T8: ErasableGenericBorrow<JsValue>,
ArrayTuple<(T1, T2, T3, T4, T5, T6, T7, T8)>: ErasableGenericOwn<ArrayTuple<(JsValue, JsValue, JsValue, JsValue, JsValue, JsValue, JsValue, JsValue)>>,
Creates a new JS array typed as a 8-tuple.
Sourceimpl<T> ArrayTuple<T>where
T: JsTuple1,
impl<T> ArrayTuple<T>where
T: JsTuple1,
Sourceimpl<T> ArrayTuple<T>where
T: JsTuple2,
impl<T> ArrayTuple<T>where
T: JsTuple2,
Sourceimpl<T> ArrayTuple<T>where
T: JsTuple3,
impl<T> ArrayTuple<T>where
T: JsTuple3,
Sourceimpl<T> ArrayTuple<T>where
T: JsTuple4,
impl<T> ArrayTuple<T>where
T: JsTuple4,
Sourceimpl<T> ArrayTuple<T>where
T: JsTuple5,
impl<T> ArrayTuple<T>where
T: JsTuple5,
Sourceimpl<T> ArrayTuple<T>where
T: JsTuple6,
impl<T> ArrayTuple<T>where
T: JsTuple6,
Sourceimpl<T> ArrayTuple<T>where
T: JsTuple7,
impl<T> ArrayTuple<T>where
T: JsTuple7,
Sourceimpl<T> ArrayTuple<T>where
T: JsTuple8,
impl<T> ArrayTuple<T>where
T: JsTuple8,
Sourceimpl<T> ArrayTuple<T>where
T: JsTuple1,
impl<T> ArrayTuple<T>where
T: JsTuple1,
Sourceimpl<T> ArrayTuple<T>where
T: JsTuple2,
impl<T> ArrayTuple<T>where
T: JsTuple2,
Sourceimpl<T> ArrayTuple<T>where
T: JsTuple3,
impl<T> ArrayTuple<T>where
T: JsTuple3,
Sourceimpl<T> ArrayTuple<T>where
T: JsTuple4,
impl<T> ArrayTuple<T>where
T: JsTuple4,
Sourceimpl<T> ArrayTuple<T>where
T: JsTuple5,
impl<T> ArrayTuple<T>where
T: JsTuple5,
Sourceimpl<T> ArrayTuple<T>where
T: JsTuple6,
impl<T> ArrayTuple<T>where
T: JsTuple6,
Sourceimpl<T> ArrayTuple<T>where
T: JsTuple7,
impl<T> ArrayTuple<T>where
T: JsTuple7,
Sourceimpl<T> ArrayTuple<T>where
T: JsTuple8,
impl<T> ArrayTuple<T>where
T: JsTuple8,
Sourceimpl<T> ArrayTuple<T>where
T: JsTuple,
impl<T> ArrayTuple<T>where
T: JsTuple,
Sourceimpl<T1> ArrayTuple<(T1,)>where
T1: JsGeneric,
impl<T1> ArrayTuple<(T1,)>where
T1: JsGeneric,
Sourcepub fn into_tuple(self) -> (T1,)
pub fn into_tuple(self) -> (T1,)
Convert the ArrayTuple into its corresponding Rust tuple.
Sourcepub fn into_parts(self) -> (T1,)
👎Deprecated: renamed to into_tuple
pub fn into_parts(self) -> (T1,)
renamed to into_tuple
Deprecated alias for ArrayTuple::into_tuple.
Sourcepub fn new(get0: &T1) -> ArrayTuple<(T1,)>
pub fn new(get0: &T1) -> ArrayTuple<(T1,)>
Create a new ArrayTuple from the corresponding parts.
Example
use js_sys::{ArrayTuple, JsString};
let tuple = ArrayTuple::<JsString, JsString>::new(&"a".into(), &"b".into());Note: You must specify the T using ::<...> syntax on ArrayTuple.
Alternatively, use new1, new2, etc. for type inference from the left-hand side.
Sourceimpl<T1, T2> ArrayTuple<(T1, T2)>
impl<T1, T2> ArrayTuple<(T1, T2)>
Sourcepub fn into_tuple(self) -> (T1, T2)
pub fn into_tuple(self) -> (T1, T2)
Convert the ArrayTuple into its corresponding Rust tuple.
Sourcepub fn into_parts(self) -> (T1, T2)
👎Deprecated: renamed to into_tuple
pub fn into_parts(self) -> (T1, T2)
renamed to into_tuple
Deprecated alias for ArrayTuple::into_tuple.
Sourcepub fn new(get0: &T1, get1: &T2) -> ArrayTuple<(T1, T2)>
pub fn new(get0: &T1, get1: &T2) -> ArrayTuple<(T1, T2)>
Create a new ArrayTuple from the corresponding parts.
Example
use js_sys::{ArrayTuple, JsString};
let tuple = ArrayTuple::<JsString, JsString>::new(&"a".into(), &"b".into());Note: You must specify the T using ::<...> syntax on ArrayTuple.
Alternatively, use new1, new2, etc. for type inference from the left-hand side.
Sourceimpl<T1, T2, T3> ArrayTuple<(T1, T2, T3)>
impl<T1, T2, T3> ArrayTuple<(T1, T2, T3)>
Sourcepub fn into_tuple(self) -> (T1, T2, T3)
pub fn into_tuple(self) -> (T1, T2, T3)
Convert the ArrayTuple into its corresponding Rust tuple.
Sourcepub fn into_parts(self) -> (T1, T2, T3)
👎Deprecated: renamed to into_tuple
pub fn into_parts(self) -> (T1, T2, T3)
renamed to into_tuple
Deprecated alias for ArrayTuple::into_tuple.
Sourcepub fn new(get0: &T1, get1: &T2, get2: &T3) -> ArrayTuple<(T1, T2, T3)>
pub fn new(get0: &T1, get1: &T2, get2: &T3) -> ArrayTuple<(T1, T2, T3)>
Create a new ArrayTuple from the corresponding parts.
Example
use js_sys::{ArrayTuple, JsString};
let tuple = ArrayTuple::<JsString, JsString>::new(&"a".into(), &"b".into());Note: You must specify the T using ::<...> syntax on ArrayTuple.
Alternatively, use new1, new2, etc. for type inference from the left-hand side.
Sourceimpl<T1, T2, T3, T4> ArrayTuple<(T1, T2, T3, T4)>
impl<T1, T2, T3, T4> ArrayTuple<(T1, T2, T3, T4)>
Sourcepub fn into_tuple(self) -> (T1, T2, T3, T4)
pub fn into_tuple(self) -> (T1, T2, T3, T4)
Convert the ArrayTuple into its corresponding Rust tuple.
Sourcepub fn into_parts(self) -> (T1, T2, T3, T4)
👎Deprecated: renamed to into_tuple
pub fn into_parts(self) -> (T1, T2, T3, T4)
renamed to into_tuple
Deprecated alias for ArrayTuple::into_tuple.
Sourcepub fn new(
get0: &T1,
get1: &T2,
get2: &T3,
get3: &T4,
) -> ArrayTuple<(T1, T2, T3, T4)>
pub fn new( get0: &T1, get1: &T2, get2: &T3, get3: &T4, ) -> ArrayTuple<(T1, T2, T3, T4)>
Create a new ArrayTuple from the corresponding parts.
Example
use js_sys::{ArrayTuple, JsString};
let tuple = ArrayTuple::<JsString, JsString>::new(&"a".into(), &"b".into());Note: You must specify the T using ::<...> syntax on ArrayTuple.
Alternatively, use new1, new2, etc. for type inference from the left-hand side.
Sourceimpl<T1, T2, T3, T4, T5> ArrayTuple<(T1, T2, T3, T4, T5)>
impl<T1, T2, T3, T4, T5> ArrayTuple<(T1, T2, T3, T4, T5)>
Sourcepub fn into_tuple(self) -> (T1, T2, T3, T4, T5)
pub fn into_tuple(self) -> (T1, T2, T3, T4, T5)
Convert the ArrayTuple into its corresponding Rust tuple.
Sourcepub fn into_parts(self) -> (T1, T2, T3, T4, T5)
👎Deprecated: renamed to into_tuple
pub fn into_parts(self) -> (T1, T2, T3, T4, T5)
renamed to into_tuple
Deprecated alias for ArrayTuple::into_tuple.
Sourcepub fn new(
get0: &T1,
get1: &T2,
get2: &T3,
get3: &T4,
get4: &T5,
) -> ArrayTuple<(T1, T2, T3, T4, T5)>
pub fn new( get0: &T1, get1: &T2, get2: &T3, get3: &T4, get4: &T5, ) -> ArrayTuple<(T1, T2, T3, T4, T5)>
Create a new ArrayTuple from the corresponding parts.
Example
use js_sys::{ArrayTuple, JsString};
let tuple = ArrayTuple::<JsString, JsString>::new(&"a".into(), &"b".into());Note: You must specify the T using ::<...> syntax on ArrayTuple.
Alternatively, use new1, new2, etc. for type inference from the left-hand side.
Sourceimpl<T1, T2, T3, T4, T5, T6> ArrayTuple<(T1, T2, T3, T4, T5, T6)>
impl<T1, T2, T3, T4, T5, T6> ArrayTuple<(T1, T2, T3, T4, T5, T6)>
Sourcepub fn into_tuple(self) -> (T1, T2, T3, T4, T5, T6)
pub fn into_tuple(self) -> (T1, T2, T3, T4, T5, T6)
Convert the ArrayTuple into its corresponding Rust tuple.
Sourcepub fn into_parts(self) -> (T1, T2, T3, T4, T5, T6)
👎Deprecated: renamed to into_tuple
pub fn into_parts(self) -> (T1, T2, T3, T4, T5, T6)
renamed to into_tuple
Deprecated alias for ArrayTuple::into_tuple.
Sourcepub fn new(
get0: &T1,
get1: &T2,
get2: &T3,
get3: &T4,
get4: &T5,
get5: &T6,
) -> ArrayTuple<(T1, T2, T3, T4, T5, T6)>
pub fn new( get0: &T1, get1: &T2, get2: &T3, get3: &T4, get4: &T5, get5: &T6, ) -> ArrayTuple<(T1, T2, T3, T4, T5, T6)>
Create a new ArrayTuple from the corresponding parts.
Example
use js_sys::{ArrayTuple, JsString};
let tuple = ArrayTuple::<JsString, JsString>::new(&"a".into(), &"b".into());Note: You must specify the T using ::<...> syntax on ArrayTuple.
Alternatively, use new1, new2, etc. for type inference from the left-hand side.
Sourceimpl<T1, T2, T3, T4, T5, T6, T7> ArrayTuple<(T1, T2, T3, T4, T5, T6, T7)>
impl<T1, T2, T3, T4, T5, T6, T7> ArrayTuple<(T1, T2, T3, T4, T5, T6, T7)>
Sourcepub fn into_tuple(self) -> (T1, T2, T3, T4, T5, T6, T7)
pub fn into_tuple(self) -> (T1, T2, T3, T4, T5, T6, T7)
Convert the ArrayTuple into its corresponding Rust tuple.
Sourcepub fn into_parts(self) -> (T1, T2, T3, T4, T5, T6, T7)
👎Deprecated: renamed to into_tuple
pub fn into_parts(self) -> (T1, T2, T3, T4, T5, T6, T7)
renamed to into_tuple
Deprecated alias for ArrayTuple::into_tuple.
Sourcepub fn new(
get0: &T1,
get1: &T2,
get2: &T3,
get3: &T4,
get4: &T5,
get5: &T6,
get6: &T7,
) -> ArrayTuple<(T1, T2, T3, T4, T5, T6, T7)>
pub fn new( get0: &T1, get1: &T2, get2: &T3, get3: &T4, get4: &T5, get5: &T6, get6: &T7, ) -> ArrayTuple<(T1, T2, T3, T4, T5, T6, T7)>
Create a new ArrayTuple from the corresponding parts.
Example
use js_sys::{ArrayTuple, JsString};
let tuple = ArrayTuple::<JsString, JsString>::new(&"a".into(), &"b".into());Note: You must specify the T using ::<...> syntax on ArrayTuple.
Alternatively, use new1, new2, etc. for type inference from the left-hand side.
Sourceimpl<T1, T2, T3, T4, T5, T6, T7, T8> ArrayTuple<(T1, T2, T3, T4, T5, T6, T7, T8)>
impl<T1, T2, T3, T4, T5, T6, T7, T8> ArrayTuple<(T1, T2, T3, T4, T5, T6, T7, T8)>
Sourcepub fn into_tuple(self) -> (T1, T2, T3, T4, T5, T6, T7, T8)
pub fn into_tuple(self) -> (T1, T2, T3, T4, T5, T6, T7, T8)
Convert the ArrayTuple into its corresponding Rust tuple.
Sourcepub fn into_parts(self) -> (T1, T2, T3, T4, T5, T6, T7, T8)
👎Deprecated: renamed to into_tuple
pub fn into_parts(self) -> (T1, T2, T3, T4, T5, T6, T7, T8)
renamed to into_tuple
Deprecated alias for ArrayTuple::into_tuple.
Sourcepub fn new(
get0: &T1,
get1: &T2,
get2: &T3,
get3: &T4,
get4: &T5,
get5: &T6,
get6: &T7,
get7: &T8,
) -> ArrayTuple<(T1, T2, T3, T4, T5, T6, T7, T8)>
pub fn new( get0: &T1, get1: &T2, get2: &T3, get3: &T4, get4: &T5, get5: &T6, get6: &T7, get7: &T8, ) -> ArrayTuple<(T1, T2, T3, T4, T5, T6, T7, T8)>
Create a new ArrayTuple from the corresponding parts.
Example
use js_sys::{ArrayTuple, JsString};
let tuple = ArrayTuple::<JsString, JsString>::new(&"a".into(), &"b".into());Note: You must specify the T using ::<...> syntax on ArrayTuple.
Alternatively, use new1, new2, etc. for type inference from the left-hand side.
Methods from Deref<Target = Object>
Sourcepub fn constructor(&self) -> Function
pub fn constructor(&self) -> Function
The constructor property returns a reference to the Object constructor
function that created the instance object.
Sourcepub fn has_own_property(&self, property: &JsValue) -> bool
👎Deprecated: Use Object::hasOwn instead.
pub fn has_own_property(&self, property: &JsValue) -> bool
Use Object::hasOwn instead.
The hasOwnProperty() method returns a boolean indicating whether the
object has the specified property as its own property (as opposed to
inheriting it).
Sourcepub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn is_prototype_of(&self, value: &JsValue) -> bool
The isPrototypeOf() method checks if an object exists in another
object’s prototype chain.
Sourcepub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
The propertyIsEnumerable() method returns a Boolean indicating
whether the specified property is enumerable.
Sourcepub fn to_locale_string(&self) -> JsString
pub fn to_locale_string(&self) -> JsString
The toLocaleString() method returns a string representing the object.
This method is meant to be overridden by derived objects for
locale-specific purposes.
Sourcepub fn to_string(&self) -> JsString
pub fn to_string(&self) -> JsString
The toString() method returns a string representing the object.
Sourcepub fn to_js_string(&self) -> JsString
pub fn to_js_string(&self) -> JsString
The toString() method returns a string representing the object.
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn into_serde<T>(&self) -> Result<T, Error>where
T: for<'a> Deserialize<'a>,
👎Deprecated: causes dependency cycles, use serde-wasm-bindgen or gloo_utils::format::JsValueSerdeExt instead
pub fn into_serde<T>(&self) -> Result<T, Error>where
T: for<'a> Deserialize<'a>,
causes dependency cycles, use serde-wasm-bindgen or gloo_utils::format::JsValueSerdeExt instead
Invokes JSON.stringify on this value and then parses the resulting
JSON into an arbitrary Rust value.
This function is deprecated, due to creating a dependency cycle in
some circumstances. Use serde-wasm-bindgen or
gloo_utils::format::JsValueSerdeExt instead.
This function will first call JSON.stringify on the JsValue itself.
The resulting string is then passed into Rust which then parses it as
JSON into the resulting value.
Usage of this API requires activating the serde-serialize feature of
the wasm-bindgen crate.
Errors
Returns any error encountered when parsing the JSON into a T.
Sourcepub fn as_f64(&self) -> Option<f64>
pub fn as_f64(&self) -> Option<f64>
Returns the f64 value of this JS value if it’s an instance of a
number.
If this JS value is not an instance of a number then this returns
None.
Sourcepub fn as_string(&self) -> Option<String>
pub fn as_string(&self) -> Option<String>
If this JS value is a string value, this function copies the JS string
value into Wasm linear memory, encoded as UTF-8, and returns it as a
Rust String.
To avoid the copying and re-encoding, consider the
JsString::try_from() function from js-sys
instead.
If this JS value is not an instance of a string or if it’s not valid
utf-8 then this returns None.
UTF-16 vs UTF-8
JavaScript strings in general are encoded as UTF-16, but Rust strings
are encoded as UTF-8. This can cause the Rust string to look a bit
different than the JS string sometimes. For more details see the
documentation about the str type which contains a few
caveats about the encodings.
Sourcepub fn as_bool(&self) -> Option<bool>
pub fn as_bool(&self) -> Option<bool>
Returns the bool value of this JS value if it’s an instance of a
boolean.
If this JS value is not an instance of a boolean then this returns
None.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Tests whether this JS value is undefined
Sourcepub fn is_null_or_undefined(&self) -> bool
pub fn is_null_or_undefined(&self) -> bool
Tests whether this JS value is null or undefined
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Tests whether the type of this JS value is function.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Applies the binary in JS operator on the two JsValues.
Sourcepub fn loose_eq(&self, other: &JsValue) -> bool
pub fn loose_eq(&self, other: &JsValue) -> bool
Compare two JsValues for equality, using the == operator in JS.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Applies the binary >>> JS operator on the two JsValues.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Applies the binary / JS operator on two JsValues, catching and returning any RangeError thrown.
Sourcepub fn pow(&self, rhs: &JsValue) -> JsValue
pub fn pow(&self, rhs: &JsValue) -> JsValue
Applies the binary ** JS operator on the two JsValues.
Sourcepub fn lt(&self, other: &JsValue) -> bool
pub fn lt(&self, other: &JsValue) -> bool
Applies the binary < JS operator on the two JsValues.
Sourcepub fn le(&self, other: &JsValue) -> bool
pub fn le(&self, other: &JsValue) -> bool
Applies the binary <= JS operator on the two JsValues.
Sourcepub fn ge(&self, other: &JsValue) -> bool
pub fn ge(&self, other: &JsValue) -> bool
Applies the binary >= JS operator on the two JsValues.
Sourcepub fn gt(&self, other: &JsValue) -> bool
pub fn gt(&self, other: &JsValue) -> bool
Applies the binary > JS operator on the two JsValues.
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Applies the unary + JS operator on a JsValue. Can throw.